@@ -1,7 +1,7 @@
 package Net::Flotum;
 use strict;
 use 5.008_005;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use warnings;
 use utf8;
@@ -9,6 +9,7 @@ use Carp qw/croak confess/;
 use Moo;
 use namespace::clean;
 
+use Net::Flotum::API::Charge;
 use Net::Flotum::API::Customer;
 use Net::Flotum::API::RequestHandler;
 
@@ -19,6 +20,7 @@ has 'requester' => ( is => 'ro', builder => '_build_requester', lazy => 1 );
 has 'merchant_api_key' => ( is => 'rw', required => 1 );
 
 has 'customer_api' => ( is => 'ro', builder => '_build_customer_api', lazy => 1 );
+has 'charge_api'   => ( is => 'ro', builder => '_build_charge_api',   lazy => 1 );
 
 sub _build_requester {
     Net::Flotum::API::RequestHandler->new;
@@ -34,6 +36,12 @@ sub _build_customer_api {
     Net::Flotum::API::Customer->new( flotum => $self, );
 }
 
+sub _build_charge_api {
+    my ($self) = @_;
+
+    Net::Flotum::API::Charge->new(flotum => $self);
+}
+
 sub load_customer {
     my ( $self, %opts ) = @_;
 
@@ -70,6 +78,30 @@ sub new_customer {
     );
 }
 
+sub _new_charge {
+    my $self = shift;
+
+    return $self->customer_api->exec_new_charge(@_);
+}
+
+sub _payment_charge {
+    my $self = shift;
+
+    return $self->charge_api->exec_payment_charge(@_);
+}
+
+sub _capture_charge {
+    my $self = shift;
+
+    return $self->charge_api->exec_capture_charge(@_);
+}
+
+sub _refund_charge {
+    my $self = shift;
+
+    return $self->charge_api->exec_refund_charge(@_);
+}
+
 sub _get_customer_data {
     my ( $self, %opts ) = @_;
 
@@ -187,6 +219,31 @@ Net-Flotum - use Flotum as your payment gateway
     # returns a list of Net::Flotum::Object::CreditCard
     @credit_cards = $customer->list_credit_cards();
 
+    # Creating a charge.
+    my $charge = $customer->new_charge(
+        amount   => 100,
+        currency => 'bra',
+        metadata => {
+            'Please use' => 'The way you need',
+            'but'        => 'Do not use more than 10000 bytes after encoded in JSON',
+        }
+    );
+
+    # Doing payment.
+    my $payment = $charge->payment(
+        customer_credit_card_id => $customer_credit_card_id,
+        csc_check               => '000',
+    );
+
+    # Capture.
+    my $capture = $charge->capture(description => "is optional");
+    print $capture->{transaction_status} . "\n"; # authorized
+
+    # Refund.
+    my $refund = $charge->refund();
+    print $refund->{status} . "\n";             # aborted
+    print $refund->{transaction_status} . "\n"; # in-cancellation
+
 
 =head1 DESCRIPTION
 
